@@ -5,7 +5,7 @@
 ;; Author: James Cherti
 ;; URL: https://github.com/jamescherti/easysession.el
 ;; Keywords: convenience
-;; Package-Requires: ((emacs "25.1"))
+;; Package-Requires: ((emacs "26.1"))
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
 ;; This file is free software; you can redistribute it and/or modify
@@ -51,6 +51,11 @@
         ;; Load
         #'(lambda (session-data)
             "Load SESSION-DATA."
+            (unless (member "*scratch*"
+                            easysession-visible-buffer-list-include-names)
+              (add-to-list 'easysession-visible-buffer-list-include-names
+                           "*scratch*"))
+
             ;; Load the scratch buffer
             (let (buffer-string)
               (catch 'done
